{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="stylesheet" href="{% static '/css/style.css' %}" />
    <title>Login</title>
  </head>
  <body>
    <div class="auth-container">
      <h1>Login</h1>
      <form method="post" enctype="multipart/form-data">
        {% csrf_token %}
        <input name="username" class="input-field" type="email" placeholder="Email" autocomplete="username" required autofocus />
        <input name="password" class="input-field" type="password" placeholder="Password" required />
        <button class="submit-button" type="submit">Submit</button>
      </form>
      <div class="links">
        <a href="{% url 'register' %}">Don't have an account yet?</a>
        <a href="{% url 'password_reset' %}">Forgot password?</a>
      </div>
    </div>
  </body>
</html>
